@@ -7,6 +7,7 @@
 
 # Package imports.
 from . import xmlwriter
+from .utility import encode_utf8
 
 
 class App(xmlwriter.XMLwriter):
@@ -158,19 +159,18 @@ class App(xmlwriter.XMLwriter):
         self._xml_data_element("vt:%s" % vt_data[0], vt_data[1])
 
     def _write_company(self):
-        if 'company' in self.properties:
-            company = self.properties['company']
-        else:
-            company = ''
+        company = self.properties.get('company', '')
 
-        self._xml_data_element('Company', company)
+        self._xml_data_element('Company', encode_utf8(company))
 
     def _write_manager(self):
         # Write the <Manager> element.
         if not 'manager' in self.properties:
             return
 
-        self._xml_data_element('Manager', self.properties['manager'])
+        manager = encode_utf8(self.properties['manager'])
+
+        self._xml_data_element('Manager', manager)
 
     def _write_links_up_to_date(self):
         # Write the <LinksUpToDate> element.
