@@ -9,7 +9,6 @@
 
 # Standard packages.
 import re
-import codecs
 
 
 class XMLwriter(object):
@@ -33,7 +32,7 @@ class XMLwriter(object):
         # done using _set_filehandle(), usually for testing, or later via
         # this method, when assembling the xlsx file.
         self.internal_fh = True
-        self.fh = codecs.open(filename, 'w', 'utf-8')
+        self.fh = open(filename, 'w')
 
     def _xml_close(self):
         # Close the XML filehandle if we created it.
